"""
This migrations was made necessary due to OrgReg using the same short
name for multiple OrganizationUnits.

The restriction existed to prevent multiple units having the same
legacy_stedkode. This should never be the case but this value is not
used for anything other than clarity when choosing an OrganizationUnit
from a dropdown in the frontend and should thus be safe.
"""
# Generated by Django 4.1.3 on 2022-11-29 11:44

from django.db import migrations, models


def cleanup_duplicates(apps, schema_editor):
    """
    Keep most recently updated value for each name on each ou
    """
    OuIdentifier = apps.get_model("greg", "OuIdentifier")
    previous = None
    for oui in OuIdentifier.objects.order_by("name", "orgunit", "updated"):
        if (
            previous
            and oui.name == previous.name
            and oui.orgunit.id == previous.orgunit.id
        ):
            previous.delete()
        previous = oui
    return


class Migration(migrations.Migration):

    dependencies = [
        ("greg", "0025_alter_ouidentifier_source"),
    ]

    operations = [
        migrations.RunPython(cleanup_duplicates),
        migrations.RemoveConstraint(
            model_name="ouidentifier",
            name="unique_identifier",
        ),
        migrations.AddConstraint(
            model_name="ouidentifier",
            constraint=models.UniqueConstraint(
                fields=("name", "orgunit"), name="unique_identifier"
            ),
        ),
    ]
